@@ -82,7 +82,7 @@ void MySQLWriter::printForeignKeyConstraints(QTextStream& sql, UMLClassifierList
 {
     // we need to create an index on the referenced attributes before we can create a foreign key constraint in MySQL
 
-    foreach(UMLClassifierListItem* cli, constrList) {
+    for(UMLClassifierListItem* cli : constrList) {
         UMLForeignKeyConstraint* fkc = cli->asUMLForeignKeyConstraint();
 
         QMap<UMLEntityAttribute*, UMLEntityAttribute*> attributeMap = fkc->getEntityAttributePairs();
@@ -92,7 +92,7 @@ void MySQLWriter::printForeignKeyConstraints(QTextStream& sql, UMLClassifierList
 
         // convert to UMLEntityAttributeList
         UMLEntityAttributeList refAttList;
-        foreach(UMLEntityAttribute* ea, eaList) {
+        for(UMLEntityAttribute* ea : eaList) {
             refAttList.append(ea);
         }
 
@@ -113,15 +113,15 @@ void MySQLWriter::printAutoIncrements(QTextStream& sql, const UMLEntityAttribute
     // and that attribute should have an index on it :/
 
     // get the first attribute of list with auto increment
-    UMLEntityAttribute* autoIncrementEntAtt = 0;
-    foreach(UMLEntityAttribute* ea, entAttList) {
+    UMLEntityAttribute *autoIncrementEntAtt = nullptr;
+    for(UMLEntityAttribute* ea : entAttList) {
        if (ea->getAutoIncrement()) {
            autoIncrementEntAtt = ea;
            break;
        }
     }
 
-    if (autoIncrementEntAtt == 0) {
+    if (autoIncrementEntAtt == nullptr) {
         return;
     }
 
