@@ -10,7 +10,7 @@
 #include "attribute.h"
 #include "classifier.h"
 #include "codeimpthread.h"
-#define DBG_SRC QLatin1String("CsValaImportBase")
+#define DBG_SRC QStringLiteral("CsValaImportBase")
 #include "debug_utils.h"
 #include "enum.h"
 #include "import_utils.h"
@@ -22,7 +22,7 @@
 
 // qt includes
 #include <QFile>
-#include <QRegExp>
+#include <QRegularExpression>
 #include <QStringList>
 #include <QTextStream>
 
@@ -35,11 +35,11 @@ int CsValaImportBase::s_parseDepth = 0;
  * Constructor.
  */
 CsValaImportBase::CsValaImportBase(CodeImpThread* thread)
-  : NativeImportBase(QLatin1String("//"), thread),
+  : NativeImportBase(QStringLiteral("//"), thread),
     m_defaultCurrentAccess(Uml::Visibility::Public)
 {
     m_language = Uml::ProgrammingLanguage::CSharp;
-    setMultiLineComment(QLatin1String("/*"), QLatin1String("*/"));
+    setMultiLineComment(QStringLiteral("/*"), QStringLiteral("*/"));
     initVars();
 }
 
@@ -74,7 +74,7 @@ QString CsValaImportBase::joinTypename(const QString& typeName)
     QString typeNameRet(typeName);
     QString next = lookAhead();
     if (!next.isEmpty()) {
-        if (next == QLatin1String("<") || next == QLatin1String("[")) {
+        if (next == QStringLiteral("<") || next == QStringLiteral("[")) {
             int start = ++m_srcIndex;
             if (! skipToClosing(m_source[start][0]))
                 return typeNameRet;
@@ -84,7 +84,7 @@ QString CsValaImportBase::joinTypename(const QString& typeName)
         }
     }
     // to handle multidimensional arrays, call recursively
-    if (lookAhead() == QLatin1String("[")) {
+    if (lookAhead() == QStringLiteral("[")) {
         typeNameRet = joinTypename(typeNameRet);
     }
     return typeNameRet;
@@ -134,11 +134,11 @@ void CsValaImportBase::fillSource(const QString& word)
     // Condense single dimension array into the type name as done for the
     // predefined types in the CSharpWriter and ValaWriter code generators.
     const int last = m_source.size() - 1;
-    if (last > 1 && m_source.at(last-1) == QLatin1String("[")
-                   && m_source.at(last) == QLatin1String("]")) {
+    if (last > 1 && m_source.at(last-1) == QStringLiteral("[")
+                   && m_source.at(last) == QStringLiteral("]")) {
         m_source.removeLast();
         m_source.removeLast();
-        m_source.last() += QLatin1String("[]");
+        m_source.last() += QStringLiteral("[]");
     }
 }
 
@@ -201,7 +201,7 @@ UMLObject* CsValaImportBase::resolveClass(const QString& className)
 
     // the file we're looking for might be in the same directory as the
     // current class
-    QString myDir = file.join(QLatin1String("/"));
+    QString myDir = file.join(QStringLiteral("/"));
     QString myFile = myDir + QLatin1Char('/') + baseClassName + fileExtension();
     if (QFile::exists(myFile)) {
         spawnImport(myFile);
@@ -223,7 +223,7 @@ UMLObject* CsValaImportBase::resolveClass(const QString& className)
         file.pop_back();
     }
     // this is now the root of any further source imports
-    QString sourceRoot = file.join(QLatin1String("/")) + QLatin1Char('/');
+    QString sourceRoot = file.join(QStringLiteral("/")) + QLatin1Char('/');
 
     for (QStringList::Iterator pathIt = m_imports.begin();
             pathIt != m_imports.end(); ++pathIt) {
@@ -233,13 +233,13 @@ UMLObject* CsValaImportBase::resolveClass(const QString& className)
         if (import.endsWith(QLatin1Char('*')) || import.endsWith(baseClassName)) {
             // check if the file we want is in this imported package
             // convert the org.test type package into a filename
-            QString aFile = sourceRoot + split.join(QLatin1String("/")) + QLatin1Char('/') + baseClassName + fileExtension();
+            QString aFile = sourceRoot + split.join(QStringLiteral("/")) + QLatin1Char('/') + baseClassName + fileExtension();
             if (QFile::exists(aFile)) {
                 spawnImport(aFile);
                 // we need to set the package for the class that will be resolved
                 // start at the root package
-                UMLPackage *parent = 0;
-                UMLPackage *current = 0;
+                UMLPackage  *parent = nullptr;
+                UMLPackage  *current = nullptr;
 
                 for (QStringList::Iterator it = split.begin(); it != split.end(); ++it) {
                     QString name = (*it);
@@ -258,7 +258,7 @@ UMLObject* CsValaImportBase::resolveClass(const QString& className)
             } // if file exists
         } // if import matches
     } //foreach import
-    return 0; // no match
+    return nullptr; // no match
 }
 
 /**
@@ -300,15 +300,15 @@ bool CsValaImportBase::parseStmt()
     QString keyword = m_source[m_srcIndex];
     //uDebug() << '"' << keyword << '"';
 
-    if (keyword == QLatin1String("using")) {
+    if (keyword == QStringLiteral("using")) {
         return parseUsingDirectives();
     }
 
-    if (keyword == QLatin1String("namespace")) {
+    if (keyword == QStringLiteral("namespace")) {
         return parseNamespaceMemberDeclarations();
     }
 
-    if (keyword == QLatin1String("[")) {
+    if (keyword == QStringLiteral("[")) {
         return parseAttributes();  //:TODO: more than one
     }
 
@@ -318,26 +318,26 @@ bool CsValaImportBase::parseStmt()
 
     // type-declaration - class, interface, struct, enum, delegate
     if (isTypeDeclaration(keyword)) {
-        if (keyword == QLatin1String("struct")) {
+        if (keyword == QStringLiteral("struct")) {
             return parseStructDeclaration();
         }
-        if (keyword == QLatin1String("enum")) {
+        if (keyword == QStringLiteral("enum")) {
             return parseEnumDeclaration();
         }
-        if (keyword == QLatin1String("delegate")) {
+        if (keyword == QStringLiteral("delegate")) {
             return parseDelegateDeclaration();
         }
         // "class" or "interface"
         return parseClassDeclaration(keyword);
     }
 
-    if (keyword == QLatin1String("[")) {   // ...
+    if (keyword == QStringLiteral("[")) {   // ...
         advance();
         skipToClosing(QLatin1Char('['));
         return true;
     }
 
-    if (keyword == QLatin1String("}")) {
+    if (keyword == QStringLiteral("}")) {
         if (scopeIndex())
             m_klass = popScope()->asUMLClassifier();
         else
@@ -357,7 +357,7 @@ bool CsValaImportBase::parseStmt()
     // (of a member of class or interface, or return type
     // of an operation.) Up next is the name of the attribute
     // or operation.
-    if (! keyword.contains(QRegExp(QLatin1String("^\\w")))) {
+    if (! keyword.contains(QRegularExpression(QStringLiteral("^\\w")))) {
         if (m_klass)
             logError4("CsValaImportBase::parseStmt: ignoring keyword %1 at index %2 of %3 (%4)",
                       keyword, m_srcIndex, m_source.count(), m_klass->name());
@@ -369,13 +369,13 @@ bool CsValaImportBase::parseStmt()
 
     QString typeName = joinTypename(keyword);
     // At this point we need a class.
-    if (m_klass == 0) {
+    if (m_klass == nullptr) {
         logError1("CsValaImportBase::parseStmt: no class set for %1", typeName);
         return false;
     }
     QString name = advance();
     QString nextToken;
-    if (typeName == m_klass->name() && name == QLatin1String("(")) {
+    if (typeName == m_klass->name() && name == QStringLiteral("(")) {
         // Constructor.
         nextToken = name;
         name = typeName;
@@ -383,17 +383,17 @@ bool CsValaImportBase::parseStmt()
     } else {
         nextToken = advance();
     }
-    if (name.contains(QRegExp(QLatin1String("\\W")))) {
+    if (name.contains(QRegularExpression(QStringLiteral("\\W")))) {
         logError1("CsValaImportBase::parseStmt: expecting name at %1", name);
         return false;
     }
-    if (nextToken == QLatin1String("(")) {
+    if (nextToken == QStringLiteral("(")) {
         // operation
         UMLOperation *op = Import_Utils::makeOperation(m_klass, name);
         m_srcIndex++;
-        while (m_srcIndex < m_source.count() && m_source[m_srcIndex] != QLatin1String(")")) {
+        while (m_srcIndex < m_source.count() && m_source[m_srcIndex] != QStringLiteral(")")) {
             QString typeName = m_source[m_srcIndex];
-            if (typeName == QLatin1String("final") || typeName.startsWith(QLatin1String("//"))) {
+            if (typeName == QStringLiteral("final") || typeName.startsWith(QStringLiteral("//"))) {
                 // ignore the "final" keyword and any comments in method args
                 typeName = advance();
             }
@@ -403,21 +403,21 @@ bool CsValaImportBase::parseStmt()
             UMLObject *obj = resolveClass(typeName);
             if (obj) {
                 // by prepending the package, unwanted placeholder types will not get created
-                typeName = obj->fullyQualifiedName(QLatin1String("."));
+                typeName = obj->fullyQualifiedName(QStringLiteral("."));
             }
             /* UMLAttribute *att = */ Import_Utils::addMethodParameter(op, typeName, parName);
-            if (advance() != QLatin1String(","))
+            if (advance() != QStringLiteral(","))
                 break;
             m_srcIndex++;
         }
         // before adding the method, try resolving the return type
-        if (typeName == QLatin1String("void")) {
+        if (typeName == QStringLiteral("void")) {
             typeName.clear();
         } else {
             UMLObject *obj = resolveClass(typeName);
             if (obj) {
                 // using the fully qualified name means that a placeholder type will not be created.
-                typeName = obj->fullyQualifiedName(QLatin1String("."));
+                typeName = obj->fullyQualifiedName(QStringLiteral("."));
             }
         }
         Import_Utils::insertMethod(m_klass, op, m_currentAccess, typeName,
@@ -429,8 +429,8 @@ bool CsValaImportBase::parseStmt()
         // At this point we do not know whether the method has a body or not.
         do {
             nextToken = advance();
-        } while (nextToken != QLatin1String("{") && nextToken != QLatin1String(";"));
-        if (nextToken == QLatin1String(";")) {
+        } while (nextToken != QStringLiteral("{") && nextToken != QStringLiteral(";"));
+        if (nextToken == QStringLiteral(";")) {
             // No body (interface or abstract)
             return true;
         } else {
@@ -438,7 +438,7 @@ bool CsValaImportBase::parseStmt()
         }
     }
     // At this point it should be some kind of data member or property declaration.
-    if (nextToken == QLatin1String("{")) {   // property
+    if (nextToken == QStringLiteral("{")) {   // property
         // try to resolve the class type, or create a placeholder if that fails
         UMLObject *type = resolveClass(typeName);
         if (type) {
@@ -456,13 +456,13 @@ bool CsValaImportBase::parseStmt()
         return true;
     }
     while (1) {
-        while (nextToken != QLatin1String(",") && nextToken != QLatin1String(";")) {
-            if (nextToken == QLatin1String("=")) {
-                if ((nextToken = advance()) == QLatin1String("new")) {
+        while (nextToken != QStringLiteral(",") && nextToken != QStringLiteral(";")) {
+            if (nextToken == QStringLiteral("=")) {
+                if ((nextToken = advance()) == QStringLiteral("new")) {
                     advance();
-                    if ((nextToken = advance()) == QLatin1String("(")) {
+                    if ((nextToken = advance()) == QStringLiteral("(")) {
                         skipToClosing(QLatin1Char('('));
-                        if ((nextToken = advance()) == QLatin1String("{")) {
+                        if ((nextToken = advance()) == QStringLiteral("{")) {
                             skipToClosing(QLatin1Char('{'));
                         } else {
                             skipStmt();
@@ -496,7 +496,7 @@ bool CsValaImportBase::parseStmt()
                         typeName, m_comment, m_isStatic);
         }
         // UMLAttribute *attr = o->asUMLAttribute();
-        if (nextToken != QLatin1String(",")) {
+        if (nextToken != QStringLiteral(",")) {
             // reset the modifiers
             m_isStatic = m_isAbstract = false;
             break;
@@ -507,7 +507,7 @@ bool CsValaImportBase::parseStmt()
     // reset visibility to default
     m_currentAccess = m_defaultCurrentAccess;
     if (m_srcIndex < m_source.count()) {
-        if (m_source[m_srcIndex] != QLatin1String(";")) {
+        if (m_source[m_srcIndex] != QStringLiteral(";")) {
             logError1("CsValaImportBase::parseStmt: ignoring trailing items at %1", name);
             skipStmt();
         }
@@ -526,7 +526,7 @@ bool CsValaImportBase::parseStmt()
 bool CsValaImportBase::parseUsingDirectives()
 {
     QString import = advance();
-    log(QLatin1String("using ") + import);
+    log(QStringLiteral("using ") + import);
     if (import.contains(QLatin1Char('='))) {
         //this is an alias to represent the namespace name
         //:TODO: import = import + advance();
@@ -555,9 +555,9 @@ bool CsValaImportBase::parseGlobalAttributes()
 bool CsValaImportBase::parseNamespaceMemberDeclarations()
 {
     QString m_currentNamespace = advance();
-    log(QLatin1String("namespace ") + m_currentNamespace);
+    log(QStringLiteral("namespace ") + m_currentNamespace);
     // move past {
-    skipStmt(QLatin1String("{"));
+    skipStmt(QStringLiteral("{"));
     return true;
 }
 
@@ -568,8 +568,8 @@ bool CsValaImportBase::parseNamespaceMemberDeclarations()
 bool CsValaImportBase::parseAttributes()
 {
     QString attribute = advance();
-    log(QLatin1String("attribute ") + attribute);
-    skipStmt(QLatin1String("]"));
+    log(QStringLiteral("attribute ") + attribute);
+    skipStmt(QStringLiteral("]"));
     return true;
 }
 
@@ -579,11 +579,11 @@ bool CsValaImportBase::parseAttributes()
  */
 bool CsValaImportBase::isTypeDeclaration(const QString& keyword)
 {
-    if (keyword == QLatin1String("class")     ||
-        keyword == QLatin1String("struct")    ||
-        keyword == QLatin1String("interface") ||
-        keyword == QLatin1String("enum")      ||
-        keyword == QLatin1String("delegate")) {
+    if (keyword == QStringLiteral("class")     ||
+        keyword == QStringLiteral("struct")    ||
+        keyword == QStringLiteral("interface") ||
+        keyword == QStringLiteral("enum")      ||
+        keyword == QStringLiteral("delegate")) {
         // log("type-declaration: " + keyword);
         return true;
     }
@@ -599,10 +599,10 @@ bool CsValaImportBase::isTypeDeclaration(const QString& keyword)
 bool CsValaImportBase::isClassModifier(const QString& keyword)
 {
     if (isCommonModifier(keyword) ||
-        keyword == QLatin1String("sealed")) {
+        keyword == QStringLiteral("sealed")) {
         return true;
     }
-    if (keyword == QLatin1String("abstract")) {
+    if (keyword == QStringLiteral("abstract")) {
         m_isAbstract = true;
         return true;
     }
@@ -615,32 +615,32 @@ bool CsValaImportBase::isClassModifier(const QString& keyword)
  */
 bool CsValaImportBase::isCommonModifier(const QString& keyword)
 {
-    if (keyword == QLatin1String("public")) {
+    if (keyword == QStringLiteral("public")) {
         m_currentAccess = Uml::Visibility::Public;
         return true;
     }
-    if (keyword == QLatin1String("protected")) {
+    if (keyword == QStringLiteral("protected")) {
         m_currentAccess = Uml::Visibility::Protected;
         return true;
     }
-    if (keyword == QLatin1String("private")) {
+    if (keyword == QStringLiteral("private")) {
         m_currentAccess = Uml::Visibility::Private;
         return true;
     }
-    if (keyword == QLatin1String("static")) {
+    if (keyword == QStringLiteral("static")) {
         m_isStatic = true;
         return true;
     }
-    if (keyword == QLatin1String("new")       ||
-        keyword == QLatin1String("internal")  ||
-        keyword == QLatin1String("readonly")  ||
-        keyword == QLatin1String("volatile")  ||
-        keyword == QLatin1String("virtual")   ||
-        keyword == QLatin1String("override")  ||
-        keyword == QLatin1String("unsafe")    ||
-        keyword == QLatin1String("extern")    ||
-        keyword == QLatin1String("partial")   ||
-        keyword == QLatin1String("async")) {
+    if (keyword == QStringLiteral("new")       ||
+        keyword == QStringLiteral("internal")  ||
+        keyword == QStringLiteral("readonly")  ||
+        keyword == QStringLiteral("volatile")  ||
+        keyword == QStringLiteral("virtual")   ||
+        keyword == QStringLiteral("override")  ||
+        keyword == QStringLiteral("unsafe")    ||
+        keyword == QStringLiteral("extern")    ||
+        keyword == QStringLiteral("partial")   ||
+        keyword == QStringLiteral("async")) {
         return true;
     }
     return false;
@@ -653,31 +653,31 @@ bool CsValaImportBase::isCommonModifier(const QString& keyword)
 bool CsValaImportBase::parseEnumDeclaration()
 {
     const QString& name = advance();
-    log(QLatin1String("enum ") + name);
+    log(QStringLiteral("enum ") + name);
     UMLObject *ns = Import_Utils::createUMLObject(UMLObject::ot_Enum,
                         name, currentScope(), m_comment);
     UMLEnum *enumType = ns->asUMLEnum();
-    if (enumType == 0)
+    if (enumType == nullptr)
         enumType = Import_Utils::remapUMLEnum(ns, currentScope());
-    skipStmt(QLatin1String("{"));
-    while (m_srcIndex < m_source.count() - 1 && advance() != QLatin1String("}")) {
+    skipStmt(QStringLiteral("{"));
+    while (m_srcIndex < m_source.count() - 1 && advance() != QStringLiteral("}")) {
         QString next = advance();
-        if (next == QLatin1String("=")) {
+        if (next == QStringLiteral("=")) {
             next = advance();
-            if (enumType != 0)
+            if (enumType != nullptr)
                 Import_Utils::addEnumLiteral(enumType, m_source[m_srcIndex - 2], QString(), m_source[m_srcIndex]);
             next = advance();
         } else {
-            if (enumType != 0)
+            if (enumType != nullptr)
                 Import_Utils::addEnumLiteral(enumType, m_source[m_srcIndex - 1]);
         }
-        if (next == QLatin1String("{") || next == QLatin1String("(")) {
+        if (next == QStringLiteral("{") || next == QStringLiteral("(")) {
             if (! skipToClosing(next[0]))
                 return false;
             next = advance();
         }
-        if (next != QLatin1String(",")) {
-            if (next == QLatin1String(";")) {
+        if (next != QStringLiteral(",")) {
+            if (next == QStringLiteral(";")) {
                 // @todo handle methods in enum
                 // For now, we cheat (skip them)
                 m_source[m_srcIndex] = QLatin1Char('{');
@@ -697,7 +697,7 @@ bool CsValaImportBase::parseEnumDeclaration()
 bool CsValaImportBase::parseStructDeclaration()
 {
     const QString& name = advance();
-    log(QLatin1String("struct ") + name + QLatin1String(" --> parsing not yet implemented!"));
+    log(QStringLiteral("struct ") + name + QStringLiteral(" --> parsing not yet implemented!"));
     return true;
 }
 
@@ -710,8 +710,8 @@ bool CsValaImportBase::parseDelegateDeclaration()
     // return-type identifier (formal-parameter-list?) ;
     const QString& returnType = advance();
     const QString& name = advance();
-    log(QLatin1String("delegate ") + name + QLatin1String("with return-type ") + returnType);
-    skipStmt(QLatin1String(";"));
+    log(QStringLiteral("delegate ") + name + QStringLiteral("with return-type ") + returnType);
+    skipStmt(QStringLiteral(";"));
     return true;
 }
 
@@ -722,7 +722,7 @@ bool CsValaImportBase::parseDelegateDeclaration()
 bool CsValaImportBase::parseClassDeclaration(const QString& keyword)
 {
     const QString& name = advance();
-    const UMLObject::ObjectType ot = (keyword == QLatin1String("class") ? UMLObject::ot_Class
+    const UMLObject::ObjectType ot = (keyword == QStringLiteral("class") ? UMLObject::ot_Class
                                                                         : UMLObject::ot_Interface);
     log(keyword + QLatin1Char(' ') + name);
     UMLObject *ns = Import_Utils::createUMLObject(ot, name, currentScope(), m_comment);
@@ -741,10 +741,10 @@ bool CsValaImportBase::parseClassDeclaration(const QString& keyword)
         m_defaultCurrentAccess =  Uml::Visibility::Public;
     }
 
-    if (advance() == QLatin1String(";"))    // forward declaration
+    if (advance() == QStringLiteral(";"))    // forward declaration
         return true;
 
-    if (m_source[m_srcIndex] == QLatin1String("<")) {
+    if (m_source[m_srcIndex] == QStringLiteral("<")) {
         // template args - preliminary, rudimentary implementation
         // @todo implement all template arg syntax
         uint start = m_srcIndex;
@@ -754,15 +754,15 @@ bool CsValaImportBase::parseClassDeclaration(const QString& keyword)
         }
         while(1) {
             const QString arg = m_source[++start];
-            if (! arg.contains(QRegExp(QLatin1String("^[A-Za-z_]")))) {
+            if (! arg.contains(QRegularExpression(QStringLiteral("^[A-Za-z_]")))) {
                 logDebug2("import C# (%1): cannot handle template syntax (%2)", name, arg);
                 break;
             }
             /* UMLTemplate *tmpl = */ m_klass->addTemplate(arg);
             const QString next = m_source[++start];
-            if (next == QLatin1String(">"))
+            if (next == QStringLiteral(">"))
                 break;
-            if (next != QLatin1String(",")) {
+            if (next != QStringLiteral(",")) {
                 logDebug2("import C# (%1): cannot handle template syntax (%2)", name, next);
                 break;
             }
@@ -770,8 +770,8 @@ bool CsValaImportBase::parseClassDeclaration(const QString& keyword)
         advance();  // skip over ">"
     }
 
-    if (m_source[m_srcIndex] == QLatin1String(":")) {   // derivation
-        while (m_srcIndex < m_source.count() - 1 && advance() != QLatin1String("{")) {
+    if (m_source[m_srcIndex] == QStringLiteral(":")) {   // derivation
+        while (m_srcIndex < m_source.count() - 1 && advance() != QStringLiteral("{")) {
             const QString& baseName = m_source[m_srcIndex];
             // try to resolve the interface we are implementing, if this fails
             // create a placeholder
@@ -783,15 +783,15 @@ bool CsValaImportBase::parseClassDeclaration(const QString& keyword)
                           "is not resolvable. Creating placeholder", baseName);
                 Import_Utils::createGeneralization(m_klass, baseName);
             }
-            if (advance() != QLatin1String(","))
+            if (advance() != QStringLiteral(","))
                 break;
         }
     }
 
-    if (m_source[m_srcIndex] != QLatin1String("{")) {
+    if (m_source[m_srcIndex] != QStringLiteral("{")) {
         logError2("CsValaImportBase::parseClassDeclaration ignoring excess chars at %1 (index %2)",
                   name, m_source[m_srcIndex]);
-        skipStmt(QLatin1String("{"));
+        skipStmt(QStringLiteral("{"));
     }
     return true;
 }
