@@ -77,7 +77,7 @@ void UMLUniqueConstraint::copyInto(UMLObject *lhs) const
     // Copy all datamembers
     target->m_EntityAttributeList.clear();
     bool valid = true;
-    foreach(UMLEntityAttribute* attr, m_EntityAttributeList) {
+    for(UMLEntityAttribute* attr : m_EntityAttributeList) {
        if (!valid)
            break;
        valid = target->addEntityAttribute(attr);
@@ -124,7 +124,7 @@ QString UMLUniqueConstraint::toString(Uml::SignatureType::Enum sig,
         }
 
         bool first = true;
-        foreach(UMLEntityAttribute* att, m_EntityAttributeList) {
+        for(UMLEntityAttribute* att : m_EntityAttributeList) {
             if (first) {
                first = false;
             } else
@@ -158,7 +158,7 @@ void UMLUniqueConstraint::saveToXMI(QXmlStreamWriter& writer)
         writer.writeAttribute(QStringLiteral("isPrimary"), QStringLiteral("0"));
     }
 
-    foreach(UMLEntityAttribute* att, m_EntityAttributeList) {
+    for(UMLEntityAttribute* att : m_EntityAttributeList) {
         att->saveToXMI(writer);
     }
 
@@ -203,7 +203,7 @@ bool UMLUniqueConstraint::load1(QDomElement & element)
             UMLObject* obj = parentEnt->findChildObject(attName);
 
             UMLEntityAttribute* entAtt = obj->asUMLEntityAttribute();
-            if (entAtt == 0)
+            if (entAtt == nullptr)
                 continue;
 
             m_EntityAttributeList.append(entAtt);
@@ -254,13 +254,13 @@ bool UMLUniqueConstraint::addEntityAttribute(UMLEntityAttribute* attr)
         return false;
 
     }
-    if (owningParent == 0) {
+    if (owningParent == nullptr) {
         logError1("UMLUniqueConstraint::addEntityAttribute(%1) : parent is not a UMLEntity",
                   name());
         return false;
     }
 
-    if (owningParent->findChildObjectById(attr->id()) == 0) {
+    if (owningParent->findChildObjectById(attr->id()) == nullptr) {
         logError3("UMLUniqueConstraint::addEntityAttribute(%1) parent %2 does not contain attribute %3",
                   name(), owningParent->name(), attr->name());
         return false;
@@ -282,7 +282,7 @@ bool UMLUniqueConstraint::removeEntityAttribute(UMLEntityAttribute* attr)
 {
     const UMLEntity *owningParent = umlParent()->asUMLEntity();
 
-    if (owningParent == 0) {
+    if (owningParent == nullptr) {
         logError1("UMLUniqueConstraint::removeEntityAttribute(%1) : parent is not a UMLEntity", name());
         return false;
     }
