@@ -58,7 +58,7 @@ public:
     void setPostconditionText(const QString&);
 
     virtual bool showPropertiesDialog();
-    virtual void paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget = 0);
+    virtual void paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget = nullptr);
     virtual void moveWidgetBy(qreal diffX, qreal diffY);
 
     virtual bool loadFromXMI(QDomElement & qElement);
@@ -66,7 +66,7 @@ public:
 
     void constrain(qreal& width, qreal& height);
 
-signals:
+Q_SIGNALS:
     /**
      * Emitted when the activity widget is moved.
      * Provides the delta X and delta Y amount by which the widget was moved
